@@ -40,8 +40,6 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(C_get_num_procs, 0),
 	CALLMETHOD_DEF(C_get_max_threads, 0),
 	CALLMETHOD_DEF(C_set_max_threads, 1),
-	CALLMETHOD_DEF(C_get_initial_device, 0),
-	CALLMETHOD_DEF(C_pause_resource, 2),
 
 /* sparseMatrix_utils.c */
 	CALLMETHOD_DEF(C_colMins_dgCMatrix, 2),
@@ -54,7 +52,6 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(C_is_nonzero_SVT, 2),
 	CALLMETHOD_DEF(C_nzcount_SVT, 2),
 	CALLMETHOD_DEF(C_nzwhich_SVT, 3),
-	CALLMETHOD_DEF(C_nzvals_SVT, 3),
 	CALLMETHOD_DEF(C_from_SVT_SparseArray_to_Rarray, 5),
 	CALLMETHOD_DEF(C_build_SVT_from_Rarray, 3),
 	CALLMETHOD_DEF(C_from_SVT_SparseMatrix_to_CsparseMatrix, 4),
@@ -73,13 +70,12 @@ static const R_CallMethodDef callMethods[] = {
 /* SparseArray_subsetting.c */
 	CALLMETHOD_DEF(C_subset_SVT_by_Lindex, 5),
 	CALLMETHOD_DEF(C_subset_SVT_by_Mindex, 5),
-	CALLMETHOD_DEF(C_subset_SVT_as_Rarray, 5),
-	CALLMETHOD_DEF(C_subset_SVT_as_SVT, 4),
+	CALLMETHOD_DEF(C_subset_SVT_by_Nindex, 4),
 
 /* SparseArray_subassignment.c */
 	CALLMETHOD_DEF(C_subassign_SVT_by_Lindex, 6),
 	CALLMETHOD_DEF(C_subassign_SVT_by_Mindex, 6),
-	CALLMETHOD_DEF(C_subassign_SVT_with_short_Rvector, 6),
+	CALLMETHOD_DEF(C_subassign_SVT_with_short_Rvector, 5),
 	CALLMETHOD_DEF(C_subassign_SVT_with_Rarray, 6),
 	CALLMETHOD_DEF(C_subassign_SVT_with_SVT, 9),
 
@@ -138,7 +134,6 @@ static const R_CallMethodDef callMethods[] = {
 
 /* test.c */
 	CALLMETHOD_DEF(C_test, 0),
-	CALLMETHOD_DEF(C_simple_omp_parallel_for_loop, 1),
 
 	{NULL, NULL, 0}
 };
